"use strict";

var JsonML = require('jsonml.js/lib/utils');

function isHeading(tagName) {
  return /^h[1-6]$/i.test(tagName);
}

module.exports = function (markdownData, config) {
  var maxDepth = config.maxDepth || 2;
  var keepElem = config.keepElem || true;
  var listItems = JsonML.getChildren(markdownData.content).filter(function (node) {
    var tagName = JsonML.getTagName(node);
    return isHeading(tagName) && +tagName.charAt(1) <= maxDepth;
  }).map(function (node) {
    var tagName = JsonML.getTagName(node);
    var headingNodeChildren = JsonML.getChildren(node);
    var headingText = headingNodeChildren.map(function (nodeChild) {
      if (JsonML.isElement(nodeChild)) {
        if (JsonML.hasAttributes(nodeChild)) {
          return nodeChild[2] || '';
        }

        return nodeChild[1] || '';
      }

      return nodeChild;
    }).join('');
    var headingTextId = headingText.trim().replace(/\s+/g, '-');
    return ['li', ['a', {
      className: "md-tools-toc-".concat(tagName),
      href: "#".concat(headingTextId),
      title: headingText
    }].concat(keepElem ? headingNodeChildren : [headingText])];
  });
  markdownData.toc = ['ul'].concat(listItems);
  return markdownData;
};